'Windows section property program
'winSect by Charles Dietz

'ver 0.9.x  03-23-06
'  - polygons() as polygonPts type now (eliminated f element)
'  - dimension arcs(numNodes, 9)... a row for each node
'  - arcs(i, 3) = fillet radius at node i of polygon (fillet test)
'  - added option to load last saved data file and included origDir (see Files/Preferences)
'  - fixed bug in addChordSegment (0 or 2*PI) plus several others throughout code
'  - enhanced identifying sections (successive RETURNS, section number shown in status panel)
'  - fixed bug printing chord segments
'ver 1.0.x (03-30-06)
'  - add new section type, radial block
'  - changed syntax: use directional arrow keys instead of U, D, L, R
'  - improved editing of data
'  - added fill section view
'ver 1.1.x (04-08-06)
'  - improved filling sections for total fill as well as section id (GRAPHICS PAINT)
'ver 1.2.0 (06-17-06)
'  - corrected closure of arc sections for printing
'ver 1.2.1 (06-28-08)
'  - improved undo last node feature
'  - corrected plot routine when viewing one-section or net-section
'  - added show-normal parameters to initialize routine
'ver 1.2.2 (05-26-10)
'  - changed data storage from _DOCUMENTS to _APPDATA
'  - corrected path for help file
'  - made changes for PB9.04 (ISFILE & ISFOLDER plus some others)
'------------------------------------------------------------------------------------------------

%ID_Listbox            = 101
%ID_Frame              = 102
%ID_Command            = 103
%ID_Syntax             = 104
%ID_Values             = 105
%ID_Graph              = 106
%ID_Ok                 = 107
%ID_NumDigits          = 108
%ID_LastFile           = 109
%ID_StatusBar          = 110

%IDM_Open              = 201
%IDM_Save              = 202
%IDM_SaveAs            = 203
%IDM_Print             = 204
%IDM_Pref              = 205
%IDM_Exit              = 206

%IDM_Begin             = 301
%IDM_EditData          = 302
%IDM_SectWts           = 303
%IDM_DeleteSect        = 304
%IDM_RestoreSect       = 305
%IDM_xReflection       = 306
%IDM_yReflection       = 307
%IDM_RemoveAids        = 308

%IDM_LineProp          = 401
%IDM_CalcCG            = 402
%IDM_CalcAxes          = 403

%IDM_ViewNormal        = 501
%IDM_ViewNoNodes       = 502
%IDM_ViewPrinAxes      = 503
%IDM_ViewOne           = 504
%IDM_IdentSect         = 505
%IDM_FillSect          = 506
%IDM_MagnSect          = 507
%IDM_ShowAids          = 508
%IDM_HideAids          = 509
%IDM_ViewLog           = 510

%IDM_Help              = 601
%IDM_About             = 602

TYPE sectType
   nType  AS BYTE     '0=polygon, 1=circle, 2=pie, chord, or arc segment, 3=merge data, 4=radial block
   flag   AS BYTE     'bit 0=closed, 1=off, 2=deleted, 3=xReflection, 4=yReflection
   first  AS LONG     'first node of polygon
   last   AS LONG     'last node of polygon, node for other type
   wt     AS SINGLE   'weighted value
END TYPE

TYPE polygonPts
   x AS SINGLE
   y AS SINGLE
END TYPE

TYPE polygonArray
   count AS LONG
   pts(1 TO 250) AS polygonPts
END TYPE

TYPE lineType 'y = b + mx
   b AS DOUBLE
   m AS DOUBLE
END TYPE

GLOBAL hDlg AS DWORD
GLOBAL hMenu AS DWORD
GLOBAL hGraph AS DWORD
GLOBAL hdc AS DWORD
GLOBAL hCalc AS DWORD
GLOBAL hStatusBar AS DWORD
GLOBAL ghKbdHook AS DWORD
GLOBAL dataFolder AS STRING
GLOBAL descr() AS STRING
GLOBAL sect() AS sectType
GLOBAL polygons() AS polygonPts
GLOBAL arcs() AS SINGLE
GLOBAL maxNodes AS LONG
GLOBAL numNodes AS LONG
GLOBAL numAids AS LONG
GLOBAL numItems AS BYTE
GLOBAL designAid AS BYTE
GLOBAL RAD, PI, twoPI AS DOUBLE
GLOBAL nodeNo AS LONG
GLOBAL sectNo AS LONG
GLOBAL editNode AS LONG
GLOBAL lastSect AS LONG
GLOBAL numSections AS LONG
GLOBAL myPrintOn AS LONG
GLOBAL viewOne AS LONG
GLOBAL inputStr AS STRING
GLOBAL Prop() AS DOUBLE
GLOBAL sectProp() AS DOUBLE
GLOBAL calcProp() AS STRING
GLOBAL noClear AS BYTE
GLOBAL viewPrinAxes AS BYTE
GLOBAL viewWithoutNodes AS BYTE
GLOBAL showAids AS BYTE
GLOBAL intersect AS BYTE
GLOBAL calcMode AS BYTE
GLOBAL calcDone AS BYTE
GLOBAL menuMode AS BYTE
GLOBAL fillSect AS LONG
GLOBAL zoom AS DOUBLE
GLOBAL xZoom AS DOUBLE
GLOBAL yZoom AS DOUBLE
GLOBAL xMax AS DOUBLE
GLOBAL xMin AS DOUBLE
GLOBAL yMax AS DOUBLE
GLOBAL yMin AS DOUBLE
GLOBAL angle AS DOUBLE
GLOBAL radius AS DOUBLE
GLOBAL AREA, XCG, YCG, CGIXX, CGIYY, CGIXY AS DOUBLE
GLOBAL IPP, IQQ, prinAngle AS DOUBLE
GLOBAL gPrinterSelected AS STRING
GLOBAL gLastPrinterSelected AS STRING
GLOBAL origDir AS STRING
GLOBAL thisFile AS STRING
GLOBAL fileChanged AS BYTE
GLOBAL numDigits AS BYTE
GLOBAL lastFile AS BYTE
GLOBAL ioMode AS BYTE
GLOBAL xrefl AS BYTE
GLOBAL yrefl AS BYTE
GLOBAL refPt AS INTEGER
GLOBAL xRef AS DOUBLE
GLOBAL yRef AS DOUBLE

DECLARE SUB addMenu(LONG)
DECLARE SUB addStatusBar()
DECLARE SUB initialize()
DECLARE SUB beginNew()
DECLARE SUB showStatus(STRING, OPT BYVAL LONG)
DECLARE SUB prepareForInput()
DECLARE SUB updatePlot()
DECLARE SUB xReflection()
DECLARE SUB yReflection()
DECLARE SUB copySect(LONG, DOUBLE, DOUBLE)
DECLARE SUB rotateSect(LONG, DOUBLE, DOUBLE, DOUBLE)
DECLARE SUB lineProp(DOUBLE, DOUBLE, DOUBLE, DOUBLE)
DECLARE SUB fillet(DOUBLE, LONG)
DECLARE SUB calculate()
DECLARE SUB calcOtherAxes(DOUBLE, DOUBLE, DOUBLE)
DECLARE SUB addLineSeg(DOUBLE, DOUBLE, DOUBLE, DOUBLE)
DECLARE SUB addCircleSect(DOUBLE, DOUBLE, DOUBLE)
DECLARE SUB addChordSeg(LONG, SINGLE, SINGLE, SINGLE, SINGLE, SINGLE)
DECLARE SUB addArcSeg(LONG)
DECLARE SUB logFile()
DECLARE SUB preferences()
DECLARE SUB openIniFile()
DECLARE SUB saveIniFile()
DECLARE SUB openTheFile()
DECLARE SUB saveTheFile()
DECLARE SUB printSect()
DECLARE SUB showAbout()
DECLARE FUNCTION getSection(LONG) AS LONG
DECLARE FUNCTION doNotQuit() AS LONG
DECLARE FUNCTION intersection(STRING, DOUBLE, DOUBLE) AS LONG
DECLARE FUNCTION fixedRadius(STRING, DOUBLE, DOUBLE) AS LONG
DECLARE FUNCTION pointInsidePolygon(LONG, DOUBLE, DOUBLE) AS LONG
DECLARE FUNCTION createFolder(STRING) AS LONG
DECLARE FUNCTION fileExists(STRING) AS LONG
DECLARE FUNCTION folderExists(STRING) AS LONG
DECLARE FUNCTION SpecialFolder(BYVAL DWORD) AS STRING
DECLARE FUNCTION HtmlHelp LIB "hhctrl.ocx" ALIAS "HtmlHelpA" _
          (BYVAL LONG, ASCIIZ, BYVAL LONG, BYVAL LONG ) AS LONG
'________________________________________________________________________________________
'Fillets:
'  fillet at node i with radius, r
'          k:    1   2   3   4   5   6   7   8   9
'  arcs(i, k)    xc  yc  r   a1  a2  x1  y1  x2  y2
'
'Circle Section:
'  circle at node i with radius, r
'          k:    1   2   3
'  arcs(i, k)    xc  yc  r
'
'Arc Sections:
'  arc segment at node i
'          k:    1   2   3   4   5   6
'  arcs(i, k)    xc  yc  r   a1  a2  t
'
'  pie section, t = 0
'  chord section, t = -1
'  ring section, a1 = a2 = 0
'
'Merge Section:
'  merge section at node i
'          k:    1   2   3    4    5    6
'  arcs(i, k)    A   xc  yc  Ixx  Iyy  Ixy
